import { Command, HelpSection, Interfaces } from '@oclif/core';
export interface SfCommandInterface extends Interfaces.Command {
    configurationVariablesSection?: HelpSection;
    envVariablesSection?: HelpSection;
    errorCodes?: HelpSection;
}
/**
 * A base command that provides convenient access to CLI help
 * output formatting. Extend this command and set specific properties
 * to add help sections to the command's help output.
 *
 * @extends @oclif/command
 * @see https://github.com/oclif/command
 */
export declare abstract class SfCommand<T> extends Command {
    static configurationVariablesSection?: HelpSection;
    static envVariablesSection?: HelpSection;
    static errorCodes?: HelpSection;
    protected toSuccessJson(result: T): SfCommand.Json<T>;
    protected toErrorJson(error: Error): SfCommand.Error;
    abstract run(): Promise<T>;
}
export declare namespace SfCommand {
    interface Json<T> {
        status: number;
        result: T;
        warnings?: string[];
    }
    interface Error {
        status: number;
        name: string;
        message: string;
        stack: string | undefined;
        warnings?: string[];
    }
}
